@@ -32,7 +32,7 @@ setMethod("joint",
 
             RET <- matrix(RET[order(o)], nrow = nrow(z), ncol = ncol(z),
                           dimnames = dimnames(z))
-            class(RET) <- "pvalue"
+            class(RET) <- c("pvalue", "matrix")
             RET
         } else {
             stop("cannot compute step-down adjusted p-values for objects of class ",
@@ -86,7 +86,7 @@ setMethod("joint",
 
             RET <- matrix(RET[order(o)], nrow = nrow(z), ncol = ncol(z),
                           dimnames = dimnames(z))
-            class(RET) <- "pvalue"
+            class(RET) <- c("pvalue", "matrix")
             RET
         }
     }
@@ -125,7 +125,7 @@ setMethod("joint",
 
             RET <- matrix(RET[order(o)], nrow = nrow(z), ncol = ncol(z),
                           dimnames = dimnames(z))
-            class(RET) <- "pvalue"
+            class(RET) <- c("pvalue", "matrix")
         }
 
         attr(RET, "nresample") <- object2@nresample
@@ -177,7 +177,7 @@ setMethod("marginal",
 
         RET <- matrix(RET, nrow = nrow(z), ncol = ncol(z),
                       dimnames = dimnames(z))
-        class(RET) <- "pvalue"
+        class(RET) <- c("pvalue", "matrix")
         RET
     }
 )
@@ -232,7 +232,7 @@ setMethod("marginal",
             RET <- cummax(RET)[order(o)] # enforce monotonicity
 
         attributes(RET) <- a # set dim and dimnames
-        class(RET) <- "pvalue"
+        class(RET) <- c("pvalue", "matrix")
         attr(RET, "nresample") <- object2@nresample
         RET
     }
@@ -265,7 +265,7 @@ setMethod("unadjusted",
 
         RET <- matrix(RET, nrow = nrow(z), ncol = ncol(z),
                       dimnames = dimnames(z))
-        class(RET) <- "pvalue"
+        class(RET) <- c("pvalue", "matrix")
         RET
     }
 )
@@ -294,7 +294,7 @@ setMethod("unadjusted",
 
         RET <- matrix(RET, nrow = nrow(z), ncol = ncol(z),
                       dimnames = dimnames(z))
-        class(RET) <- "pvalue"
+        class(RET) <- c("pvalue", "matrix")
         attr(RET, "nresample") <- object2@nresample
         RET
     }
