@@ -10,10 +10,8 @@ symmetry_test.formula <- function(formula, data = list(), subset = NULL,
 
 symmetry_test.table <- function(object, ...) {
 
-    object <- table2df_sym(object)
-    object <- new("SymmetryProblem", x = object["conditions"],
-                  y = object["response"])
-    do.call("symmetry_test", c(list(object = object), list(...)))
+    do.call("symmetry_test",
+            c(list(object = table2SymmetryProblem(object)), list(...)))
 }
 
 symmetry_test.SymmetryProblem <- function(object,
@@ -53,16 +51,16 @@ symmetry_test.SymmetryProblem <- function(object,
     ## check type of test statistic and alternative
     if (!is_scalar(object)) {
         if (teststat == "scalar") {
-            warning("Length linear statistic > 1, using ",
-                    sQuote("maximum"), "-type test statistic")
+            warning("linear statistic has length > 1: ",
+                    "using maximum test statistic instead")
             teststat <- "maximum"
         }
     } else {
         if (teststat == "maximum") teststat <- "scalar"
     }
     if (alternative != "two.sided" && teststat == "quadratic")
-        warning(sQuote("alternative"), " is ignored for ",
-                teststat, " test statistics")
+        warning(sQuote("alternative"),
+                " is ignored for quadratic test statistic")
 
     ## compute linear statistic, conditional expectation and
     ## conditional covariance
