@@ -131,11 +131,13 @@ consal_trafo <- function(x, ties.method = c("mid-ranks", "average-scores"),
     cs <- function(a) {
         switch(ties.method,
             "mid-ranks" = {
-                (rank_trafo(x) / (sum(!is.na(x)) + 1))^(a - 1)},
+                (rank_trafo(x) / (sum(!is.na(x)) + 1))^(a - 1)
+            },
             "average-scores" = {
                  s <- (rank_trafo(x, ties.method = "random") /
                          (sum(!is.na(x)) + 1))^(a - 1)
-                 average_scores(s, x)}
+                 average_scores(s, x)
+            }
         )
     }
 
@@ -172,7 +174,7 @@ maxstat_trafo <- ofmaxstat_trafo <-
     }
     qx <- quantile(x, probs = c(minprob, maxprob), na.rm = TRUE, names = FALSE,
                    type = 1)
-    if (diff(qx) < .Machine$double.eps)
+    if (diff(qx) < eps)
         return(NULL)
     cp <- sort(unique(x))
     cp <- cp[-length(cp)]
@@ -250,9 +252,8 @@ logrank_trafo <-
     ties.method <- match.arg(ties.method)
 
     if (!(is.Surv(x) && isTRUE(attr(x, "type") == "right")))
-        stop(sQuote(deparse(substitute(x))),
-             " is not an object of class ", dQuote("Surv"),
-             " representing right-censored data")
+        stop(sQuote(deparse(substitute(x))), " is not of class ",
+             dQuote("Surv"), " representing right-censored data")
 
     cc <- complete.cases(x)
     time <- x[cc, 1]
@@ -385,7 +386,7 @@ logrank_weight <-
 f_trafo <- function(x) {
     mf <- model.frame(~ x, na.action = na.pass, drop.unused.levels = TRUE)
     if (nlevels(mf$x) == 1)
-        stop("Can't deal with factors containing only one level")
+        stop("can't deal with factors containing only one level")
     ## construct design matrix _without_ intercept
     mm <- model.matrix(~ x - 1, data = mf)
     colnames(mm) <- levels(mf$x)
@@ -419,13 +420,52 @@ of_trafo <- function(x, scores = NULL) {
         stop(sQuote("scores"), " does not match the number of levels")
 }
 
+### Zheng (2008)
+ordered_scores <- function(r, s) {
+    n <- length(s)
+    if (r == 1)      # 'x' has three levels => simplest case!
+        matrix(s, nrow = 1, ncol = n)
+    else if (n == 1) # => all order-preserving binary partitions
+        matrix(s, nrow = r, ncol = 1)
+    else {           # 'x' has four or more levels
+        s1 <- ordered_scores(r - 1, s)
+        s2 <- ordered_scores(r, s[-1])
+        cbind(rbind(s[1], s1), s2)
+    }
+}
+
+zheng_trafo <- function(x, increment = 0.1) {
+    if (!is.ordered(x))
+        warning(sQuote(deparse(substitute(x))), " is not an ordered factor")
+    if (increment <= 0 || increment > 1)
+        stop(sQuote("increment"),
+             " must be greater than 0, but not greater than 1")
+    r <- nlevels(x) - 2
+    if(r == 0)
+        stop(sQuote(deparse(substitute(x))), " has less than three levels")
+
+    ## compute scores
+    scores <- rbind(0, ordered_scores(r, seq.int(0, 1, increment)), 1)
+
+    ## compute colnames
+    cn <- format(scores, digits = min(n_decimal_digits(increment), 4),
+                 scientific = FALSE)
+    cn <- vapply(seq_len(ncol(cn)), function(i)
+                     paste0(if (is_ytrafo()) "eta" else "gamma",
+                            " = (", paste0(cn[, i], collapse = ", "), ")"),
+                 NA_character_)
+
+    setDimnames(scores[x, , drop = FALSE], list(seq_along(x), cn))
+}
+
 ### transformation function
 trafo <- function(data, numeric_trafo = id_trafo, factor_trafo = f_trafo,
                   ordered_trafo = of_trafo, surv_trafo = logrank_trafo,
                   var_trafo = NULL, block = NULL) {
 
     if (!(is.data.frame(data) || is.list(data)))
-        stop(sQuote("data"), " is not a data.frame or list")
+        stop(sQuote("data"), " is not of class ",
+             dQuote("data.frame"), " or ", dQuote("list"))
 
 ### <FIXME> This two-pass procedure for 'block' is *very* expensive
 ###         for large datasets
@@ -489,7 +529,7 @@ trafo <- function(data, numeric_trafo = id_trafo, factor_trafo = f_trafo,
     cn <- c()
     for (i in 1:length(tr)) {
         if (nrow(tr[[i]]) != nrow(data))
-            stop("Transformation of variable ", names(tr)[i],
+            stop("transformation of variable ", names(tr)[i],
                  " are not of length / nrow", nrow(data))
         ret <- cbind(ret, tr[[i]])
         if (is.null(colnames(tr[[i]]))) {
