@@ -2,6 +2,7 @@
 ### testing the independence of a numeric variable
 ### 'y' and a binary factor 'x' (possibly blocked)
 
+suppressWarnings(RNGversion("3.5.2"))
 set.seed(290875)
 library("coin")
 isequal <- coin:::isequal
@@ -227,25 +228,61 @@ location <- data.frame(y = c(6, 20, 27, 38, 46, 51, 54, 57,
                        x = gl(2, 8))
 
 ### Wilcoxon Rank-Sum Test
-wt <- wilcox_test(y ~ x, data = location, conf.int = TRUE, di = "ex")
+wt <- wilcox_test(y ~ x, data = location, conf.int = TRUE,
+                  distribution = "exact")
 wt
 ci <- confint(wt)
 wt0 <- wilcox.test(y ~ x, data = location, conf.int = TRUE)
 stopifnot(isequal(wt0$confint, ci$confint))
 stopifnot(isequal(wt0$estimate, ci$estimate))
 
+wtx <- wilcox_test(y ~ x, data = location, conf.int = TRUE,
+                   distribution = "approximate")
+confint(wtx)
+
+wta <- wilcox_test(y ~ x, data = location, conf.int = TRUE)
+confint(wta)
+
 ### Normal Scores Test
-nt <- normal_test(y ~ x, data = location, conf.int = TRUE, di = "ex")
+nt <- normal_test(y ~ x, data = location, conf.int = TRUE,
+                  distribution = "exact")
 nt
 ci <- confint(nt)
 stopifnot(isequal(ci$conf.int, c(-6, 30)))
 stopifnot(isequal(ci$estimate, 11))
 
+ntx <- normal_test(y ~ x, data = location, conf.int = TRUE,
+                   distribution = "approximate")
+confint(ntx)
+
+nta <- normal_test(y ~ x, data = location, conf.int = TRUE)
+confint(nta)
+
 ### Median Test
-median_test(y ~ x, data = location, conf.int = TRUE, di = "ex")
+mt <- median_test(y ~ x, data = location, conf.int = TRUE,
+                  distribution = "exact")
+mt
+confint(mt)
+
+mtx <- median_test(y ~ x, data = location, conf.int = TRUE,
+                   distribution = "approximate")
+confint(mtx)
+
+mta <- median_test(y ~ x, data = location, conf.int = TRUE)
+confint(mta)
 
 ### Savage Test
-savage_test(y ~ x, data = location, conf.int = TRUE, di = "ex")
+st <- savage_test(y ~ x, data = location, conf.int = TRUE,
+                  distribution = "exact")
+st
+confint(st)
+
+stx <- savage_test(y ~ x, data = location, conf.int = TRUE,
+                   distribution = "approximate")
+confint(stx)
+
+sta <- savage_test(y ~ x, data = location, conf.int = TRUE)
+confint(sta)
 
 
 ### Scale Tests
@@ -254,40 +291,93 @@ scale <- data.frame(y = c(-101, -35, -13, 10, 130, 236, 370, 556,
                     x = gl(2, 8))
 
 ### Ansari-Bradley Test
-at <- ansari_test(y ~ x, data = scale, di = "ex",
-                  conf.int = TRUE, conf.level = 0.988)
+at <- ansari_test(y ~ x, data = scale, conf.int = TRUE, conf.level = 0.988,
+                  distribution = "exact")
 at
 ci <- confint(at)
 stopifnot(isequal(ci$conf.int, c(10, 556) / c(68, 27)))
-stopifnot(isequal(ci$estimate, mean(c(35/30, 370 / 290))))
+stopifnot(isequal(ci$estimate, mean(c(35 / 30, 370 / 290))))
+
+atx <- ansari_test(y ~ x, data = scale, conf.int = TRUE, conf.level = 0.988,
+                   distribution = "approximate")
+confint(atx)
+
+ata <- ansari_test(y ~ x, data = scale, conf.int = TRUE, conf.level = 0.988)
+confint(ata)                                                  # wrong in < 1.3-0
 
 ### Taha Test
-taha_test(y ~ x, data = scale, di = "ex",
-          conf.int = TRUE, conf.level = 0.54)
+tt <- taha_test(y ~ x, data = scale, conf.int = TRUE, conf.level = 0.51,
+                distribution = "exact")
+tt
+confint(tt)
+
+ttx <- taha_test(y ~ x, data = scale, conf.int = TRUE, conf.level = 0.51,
+                 distribution = "approximate")
+confint(ttx)
+
+tta <- taha_test(y ~ x, data = scale, conf.int = TRUE, conf.level = 0.51)
+confint(tta)                                                  # wrong in < 1.3-0
 
 ### Klotz Test
-klotz_test(y ~ x, data = scale, di = "ex",
-           conf.int = TRUE, conf.level = 0.988)
+kt <- klotz_test(y ~ x, data = scale, conf.int = TRUE, conf.level = 0.988,
+                 distribution = "exact")
+kt
+confint(kt)
+
+ktx <- klotz_test(y ~ x, data = scale, conf.int = TRUE, conf.level = 0.988,
+                  distribution = "approximate")
+confint(ktx)
+
+kta <- klotz_test(y ~ x, data = scale, conf.int = TRUE, conf.level = 0.988)
+confint(kta)                                                  # wrong in < 1.3-0
 
 ### Mood Test
-mood_test(y ~ x, data = scale, di = "ex",
-          conf.int = TRUE, conf.level = 0.988)
+mt <- mood_test(y ~ x, data = scale, conf.int = TRUE, conf.level = 0.988,
+                distribution = "exact")
+mt
+confint(mt)
+
+mtx <- mood_test(y ~ x, data = scale, conf.int = TRUE, conf.level = 0.988,
+                 distribution = "approximate")
+confint(mtx)
+
+mta <- mood_test(y ~ x, data = scale, conf.int = TRUE, conf.level = 0.988)
+confint(mta)                                                  # wrong in < 1.3-0
 
 ### Fligner-Killeen Test
-fligner_test(y ~ x, data = scale, di = "ex",
-                  conf.int = TRUE, conf.level = 0.988)
+ft <- fligner_test(y ~ x, data = scale, conf.int = TRUE, conf.level = 0.988,
+                   distribution = "exact")
+ft
+confint(ft)
+
+ftx <- fligner_test(y ~ x, data = scale, conf.int = TRUE, conf.level = 0.988,
+                    distribution = "approximate")
+confint(ftx)
+
+fta <- fligner_test(y ~ x, data = scale, conf.int = TRUE, conf.level = 0.988)
+confint(fta)                                                  # wrong in < 1.3-0
 
 ### Conover-Iman Test
-conover_test(y ~ x, data = scale, di = "ex",
-             conf.int = TRUE, conf.level = 0.988)
+ct <- conover_test(y ~ x, data = scale, conf.int = TRUE, conf.level = 0.988,
+                   distribution = "exact")
+ct
+confint(ct)
+
+ctx <- conover_test(y ~ x, data = scale, conf.int = TRUE, conf.level = 0.988,
+                    distribution = "approximate")
+confint(ctx)
+
+cta <- conover_test(y ~ x, data = scale, conf.int = TRUE, conf.level = 0.988)
+confint(cta)                                                  # wrong in < 1.3-0
 
 
 ### ties handling
-y1 <- c(14 , 18 , 2 , 4 , -5 , 14 , -3 , -1 , 1 , 6 , 3 , 3)
-x1 <- c(8 , 26 , -7 , -1 , 2 , 9 , 0 , -4 , 13 , 3 , 3 , 4)
-pvalue(wilcoxsign_test(y1~x1,alter="greater",dist=exact(),
-                       zero.method = "Wilcoxon"))
-pvalue(wilcoxsign_test(y1~x1,alter="greater",dist=exact()))
+y1 <- c(14, 18, 2, 4, -5, 14, -3, -1, 1, 6, 3, 3)
+x1 <- c(8, 26, -7, -1, 2, 9, 0, -4, 13, 3, 3, 4)
+pvalue(wilcoxsign_test(y1 ~ x1, alternative = "greater",
+                       distribution = "exact", zero.method = "Wilcoxon"))
+pvalue(wilcoxsign_test(y1 ~ x1, alternative = "greater",
+                       distribution = "exact"))
 
 
 ### Weighted logrank tests
@@ -295,7 +385,7 @@ pvalue(wilcoxsign_test(y1~x1,alter="greater",dist=exact()))
 ### Collett (2003, p. 9, Table 1.3)
 prostatic <- data.frame(
     time = c(13, 52,  6, 40, 10,  7, 66, 10, 10, 14,
-             16 , 4, 65,  5, 11, 10, 15,  5, 76, 56,
+             16,  4, 65,  5, 11, 10, 15,  5, 76, 56,
              88, 24, 51,  4, 40,  8, 18,  5, 16, 50,
              40,  1, 36,  5, 10, 91, 18,  1, 18,  6,
               1, 23, 15, 18, 12, 12, 17,  3),
@@ -317,29 +407,34 @@ prostatic <- within(prostatic,
 ### Gehan
 lt <- logrank_test(Surv(time, event) ~ group, data = prostatic,
                    type = "Gehan")
+stopifnot(identical(lt@method, "Two-Sample Gehan-Breslow Test"))
 isequal(round(statistic(lt)^2, 4), 3.8400)
 isequal(round(pvalue(lt), 4), 0.0500)
 
 ### Peto-Peto
 lt <- logrank_test(Surv(time, event) ~ group, data = prostatic,
                    type = "Fleming-Harrington", rho = 1)
+stopifnot(identical(lt@method, "Two-Sample Fleming-Harrington Test"))
 isequal(round(statistic(lt)^2, 4), 4.0657)
 isequal(round(pvalue(lt), 4), 0.0438)
 
 ### Prentice
 lt <- logrank_test(Surv(time, event) ~ group, data = prostatic,
                    type = "Prentice")
+stopifnot(identical(lt@method, "Two-Sample Prentice Test"))
 isequal(round(statistic(lt)^2, 4), 4.1229)
 isequal(round(pvalue(lt), 4), 0.0423)
 
 ### LR Altshuler
 lt <- logrank_test(Surv(time, event) ~ group, data = prostatic)
+stopifnot(identical(lt@method, "Two-Sample Logrank Test"))
 isequal(round(statistic(lt)^2, 4), 4.4343)
 isequal(round(pvalue(lt), 4), 0.0352)
 
 ### Tarone-Ware
 lt <- logrank_test(Surv(time, event) ~ group, data = prostatic,
                    type = "Tarone-Ware")
+stopifnot(identical(lt@method, "Two-Sample Tarone-Ware Test"))
 isequal(round(statistic(lt)^2, 4), 4.3443)
 isequal(round(pvalue(lt), 4), 0.0371)
 
